# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
import sys
from typing import Any, Optional, TYPE_CHECKING, cast

from azure.core.pipeline import policies
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.settings import settings
from azure.mgmt.core import ARMPipelineClient
from azure.mgmt.core.policies import ARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from ._configuration import CognitiveServicesManagementClientConfiguration
from ._utils.serialization import Deserializer, Serializer
from .operations import (
    AccountCapabilityHostsOperations,
    AccountConnectionsOperations,
    AccountsOperations,
    AgentApplicationsOperations,
    AgentDeploymentsOperations,
    CommitmentPlansOperations,
    CommitmentTiersOperations,
    ComputeOperationsOperations,
    ComputesOperations,
    DefenderForAISettingsOperations,
    DeletedAccountsOperations,
    DeploymentsOperations,
    EncryptionScopesOperations,
    LocationBasedModelCapacitiesOperations,
    ManagedComputeCapacitiesOperations,
    ManagedComputeDeploymentsOperations,
    ManagedComputeUsagesOperationGroupOperations,
    ManagedNetworkProvisionsOperations,
    ManagedNetworkSettingsOperations,
    ModelCapacitiesOperations,
    ModelsOperations,
    NetworkSecurityPerimeterConfigurationsOperations,
    Operations,
    OutboundRuleOperations,
    OutboundRulesOperations,
    PrivateEndpointConnectionsOperations,
    PrivateLinkResourcesOperations,
    ProjectCapabilityHostsOperations,
    ProjectConnectionsOperations,
    ProjectsOperations,
    QuotaTiersOperations,
    RaiBlocklistItemsOperations,
    RaiBlocklistsOperations,
    RaiContentFiltersOperations,
    RaiExternalSafetyProviderOperations,
    RaiExternalSafetyProvidersOperations,
    RaiPoliciesOperations,
    RaiToolLabelsOperations,
    RaiTopicsOperations,
    ResourceSkusOperations,
    SubscriptionRaiPolicyOperations,
    TestRaiExternalSafetyProviderOperations,
    UsagesOperations,
    WorkbenchesOperations,
    _CognitiveServicesManagementClientOperationsMixin,
)

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self  # type: ignore

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials import TokenCredential


class CognitiveServicesManagementClient(
    _CognitiveServicesManagementClientOperationsMixin
):  # pylint: disable=too-many-instance-attributes
    """Cognitive Services Management Client.

    :ivar operations: Operations operations
    :vartype operations: azure.mgmt.cognitiveservices.operations.Operations
    :ivar accounts: AccountsOperations operations
    :vartype accounts: azure.mgmt.cognitiveservices.operations.AccountsOperations
    :ivar deleted_accounts: DeletedAccountsOperations operations
    :vartype deleted_accounts: azure.mgmt.cognitiveservices.operations.DeletedAccountsOperations
    :ivar private_endpoint_connections: PrivateEndpointConnectionsOperations operations
    :vartype private_endpoint_connections:
     azure.mgmt.cognitiveservices.operations.PrivateEndpointConnectionsOperations
    :ivar deployments: DeploymentsOperations operations
    :vartype deployments: azure.mgmt.cognitiveservices.operations.DeploymentsOperations
    :ivar commitment_plans: CommitmentPlansOperations operations
    :vartype commitment_plans: azure.mgmt.cognitiveservices.operations.CommitmentPlansOperations
    :ivar encryption_scopes: EncryptionScopesOperations operations
    :vartype encryption_scopes: azure.mgmt.cognitiveservices.operations.EncryptionScopesOperations
    :ivar rai_policies: RaiPoliciesOperations operations
    :vartype rai_policies: azure.mgmt.cognitiveservices.operations.RaiPoliciesOperations
    :ivar subscription_rai_policy: SubscriptionRaiPolicyOperations operations
    :vartype subscription_rai_policy:
     azure.mgmt.cognitiveservices.operations.SubscriptionRaiPolicyOperations
    :ivar rai_blocklist_items: RaiBlocklistItemsOperations operations
    :vartype rai_blocklist_items:
     azure.mgmt.cognitiveservices.operations.RaiBlocklistItemsOperations
    :ivar rai_blocklists: RaiBlocklistsOperations operations
    :vartype rai_blocklists: azure.mgmt.cognitiveservices.operations.RaiBlocklistsOperations
    :ivar rai_topics: RaiTopicsOperations operations
    :vartype rai_topics: azure.mgmt.cognitiveservices.operations.RaiTopicsOperations
    :ivar rai_tool_labels: RaiToolLabelsOperations operations
    :vartype rai_tool_labels: azure.mgmt.cognitiveservices.operations.RaiToolLabelsOperations
    :ivar rai_content_filters: RaiContentFiltersOperations operations
    :vartype rai_content_filters:
     azure.mgmt.cognitiveservices.operations.RaiContentFiltersOperations
    :ivar network_security_perimeter_configurations:
     NetworkSecurityPerimeterConfigurationsOperations operations
    :vartype network_security_perimeter_configurations:
     azure.mgmt.cognitiveservices.operations.NetworkSecurityPerimeterConfigurationsOperations
    :ivar defender_for_ai_settings: DefenderForAISettingsOperations operations
    :vartype defender_for_ai_settings:
     azure.mgmt.cognitiveservices.operations.DefenderForAISettingsOperations
    :ivar projects: ProjectsOperations operations
    :vartype projects: azure.mgmt.cognitiveservices.operations.ProjectsOperations
    :ivar project_connections: ProjectConnectionsOperations operations
    :vartype project_connections:
     azure.mgmt.cognitiveservices.operations.ProjectConnectionsOperations
    :ivar project_capability_hosts: ProjectCapabilityHostsOperations operations
    :vartype project_capability_hosts:
     azure.mgmt.cognitiveservices.operations.ProjectCapabilityHostsOperations
    :ivar quota_tiers: QuotaTiersOperations operations
    :vartype quota_tiers: azure.mgmt.cognitiveservices.operations.QuotaTiersOperations
    :ivar agent_applications: AgentApplicationsOperations operations
    :vartype agent_applications:
     azure.mgmt.cognitiveservices.operations.AgentApplicationsOperations
    :ivar managed_compute_deployments: ManagedComputeDeploymentsOperations operations
    :vartype managed_compute_deployments:
     azure.mgmt.cognitiveservices.operations.ManagedComputeDeploymentsOperations
    :ivar compute_operations: ComputeOperationsOperations operations
    :vartype compute_operations:
     azure.mgmt.cognitiveservices.operations.ComputeOperationsOperations
    :ivar managed_compute_usages_operation_group: ManagedComputeUsagesOperationGroupOperations
     operations
    :vartype managed_compute_usages_operation_group:
     azure.mgmt.cognitiveservices.operations.ManagedComputeUsagesOperationGroupOperations
    :ivar computes: ComputesOperations operations
    :vartype computes: azure.mgmt.cognitiveservices.operations.ComputesOperations
    :ivar workbenches: WorkbenchesOperations operations
    :vartype workbenches: azure.mgmt.cognitiveservices.operations.WorkbenchesOperations
    :ivar managed_compute_capacities: ManagedComputeCapacitiesOperations operations
    :vartype managed_compute_capacities:
     azure.mgmt.cognitiveservices.operations.ManagedComputeCapacitiesOperations
    :ivar private_link_resources: PrivateLinkResourcesOperations operations
    :vartype private_link_resources:
     azure.mgmt.cognitiveservices.operations.PrivateLinkResourcesOperations
    :ivar test_rai_external_safety_provider: TestRaiExternalSafetyProviderOperations operations
    :vartype test_rai_external_safety_provider:
     azure.mgmt.cognitiveservices.operations.TestRaiExternalSafetyProviderOperations
    :ivar rai_external_safety_provider: RaiExternalSafetyProviderOperations operations
    :vartype rai_external_safety_provider:
     azure.mgmt.cognitiveservices.operations.RaiExternalSafetyProviderOperations
    :ivar rai_external_safety_providers: RaiExternalSafetyProvidersOperations operations
    :vartype rai_external_safety_providers:
     azure.mgmt.cognitiveservices.operations.RaiExternalSafetyProvidersOperations
    :ivar account_connections: AccountConnectionsOperations operations
    :vartype account_connections:
     azure.mgmt.cognitiveservices.operations.AccountConnectionsOperations
    :ivar account_capability_hosts: AccountCapabilityHostsOperations operations
    :vartype account_capability_hosts:
     azure.mgmt.cognitiveservices.operations.AccountCapabilityHostsOperations
    :ivar outbound_rule: OutboundRuleOperations operations
    :vartype outbound_rule: azure.mgmt.cognitiveservices.operations.OutboundRuleOperations
    :ivar managed_network_settings: ManagedNetworkSettingsOperations operations
    :vartype managed_network_settings:
     azure.mgmt.cognitiveservices.operations.ManagedNetworkSettingsOperations
    :ivar outbound_rules: OutboundRulesOperations operations
    :vartype outbound_rules: azure.mgmt.cognitiveservices.operations.OutboundRulesOperations
    :ivar managed_network_provisions: ManagedNetworkProvisionsOperations operations
    :vartype managed_network_provisions:
     azure.mgmt.cognitiveservices.operations.ManagedNetworkProvisionsOperations
    :ivar agent_deployments: AgentDeploymentsOperations operations
    :vartype agent_deployments: azure.mgmt.cognitiveservices.operations.AgentDeploymentsOperations
    :ivar resource_skus: ResourceSkusOperations operations
    :vartype resource_skus: azure.mgmt.cognitiveservices.operations.ResourceSkusOperations
    :ivar usages: UsagesOperations operations
    :vartype usages: azure.mgmt.cognitiveservices.operations.UsagesOperations
    :ivar commitment_tiers: CommitmentTiersOperations operations
    :vartype commitment_tiers: azure.mgmt.cognitiveservices.operations.CommitmentTiersOperations
    :ivar models: ModelsOperations operations
    :vartype models: azure.mgmt.cognitiveservices.operations.ModelsOperations
    :ivar location_based_model_capacities: LocationBasedModelCapacitiesOperations operations
    :vartype location_based_model_capacities:
     azure.mgmt.cognitiveservices.operations.LocationBasedModelCapacitiesOperations
    :ivar model_capacities: ModelCapacitiesOperations operations
    :vartype model_capacities: azure.mgmt.cognitiveservices.operations.ModelCapacitiesOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword api_version: The API version to use for this operation. Known values are
     "2026-05-15-preview" and None. Default value is None. If not set, the operation's default API
     version will be used. Note that overriding this default value may result in unsupported
     behavior.
    :paramtype api_version: str
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = CognitiveServicesManagementClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                ARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=cast(str, _endpoint), policies=_policies, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.operations = Operations(self._client, self._config, self._serialize, self._deserialize)
        self.accounts = AccountsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.deleted_accounts = DeletedAccountsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_endpoint_connections = PrivateEndpointConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.deployments = DeploymentsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.commitment_plans = CommitmentPlansOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.encryption_scopes = EncryptionScopesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_policies = RaiPoliciesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.subscription_rai_policy = SubscriptionRaiPolicyOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_blocklist_items = RaiBlocklistItemsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_blocklists = RaiBlocklistsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_topics = RaiTopicsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_tool_labels = RaiToolLabelsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.rai_content_filters = RaiContentFiltersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.network_security_perimeter_configurations = NetworkSecurityPerimeterConfigurationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.defender_for_ai_settings = DefenderForAISettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.projects = ProjectsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.project_connections = ProjectConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.project_capability_hosts = ProjectCapabilityHostsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.quota_tiers = QuotaTiersOperations(self._client, self._config, self._serialize, self._deserialize)
        self.agent_applications = AgentApplicationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.managed_compute_deployments = ManagedComputeDeploymentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.compute_operations = ComputeOperationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.managed_compute_usages_operation_group = ManagedComputeUsagesOperationGroupOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.computes = ComputesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.workbenches = WorkbenchesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_compute_capacities = ManagedComputeCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_resources = PrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.test_rai_external_safety_provider = TestRaiExternalSafetyProviderOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_external_safety_provider = RaiExternalSafetyProviderOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.rai_external_safety_providers = RaiExternalSafetyProvidersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.account_connections = AccountConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.account_capability_hosts = AccountCapabilityHostsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.outbound_rule = OutboundRuleOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_network_settings = ManagedNetworkSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.outbound_rules = OutboundRulesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.managed_network_provisions = ManagedNetworkProvisionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.agent_deployments = AgentDeploymentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.resource_skus = ResourceSkusOperations(self._client, self._config, self._serialize, self._deserialize)
        self.usages = UsagesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.commitment_tiers = CommitmentTiersOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.models = ModelsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.location_based_model_capacities = LocationBasedModelCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.model_capacities = ModelCapacitiesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )

    def send_request(self, request: HttpRequest, *, stream: bool = False, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Self:
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)
