# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import AccountsOperations  # type: ignore
from ._operations import DeletedAccountsOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import DeploymentsOperations  # type: ignore
from ._operations import CommitmentPlansOperations  # type: ignore
from ._operations import EncryptionScopesOperations  # type: ignore
from ._operations import RaiPoliciesOperations  # type: ignore
from ._operations import SubscriptionRaiPolicyOperations  # type: ignore
from ._operations import RaiBlocklistItemsOperations  # type: ignore
from ._operations import RaiBlocklistsOperations  # type: ignore
from ._operations import RaiTopicsOperations  # type: ignore
from ._operations import RaiToolLabelsOperations  # type: ignore
from ._operations import RaiContentFiltersOperations  # type: ignore
from ._operations import NetworkSecurityPerimeterConfigurationsOperations  # type: ignore
from ._operations import DefenderForAISettingsOperations  # type: ignore
from ._operations import ProjectsOperations  # type: ignore
from ._operations import ProjectConnectionsOperations  # type: ignore
from ._operations import ProjectCapabilityHostsOperations  # type: ignore
from ._operations import QuotaTiersOperations  # type: ignore
from ._operations import AgentApplicationsOperations  # type: ignore
from ._operations import ManagedComputeDeploymentsOperations  # type: ignore
from ._operations import ComputeOperationsOperations  # type: ignore
from ._operations import ManagedComputeUsagesOperationGroupOperations  # type: ignore
from ._operations import ComputesOperations  # type: ignore
from ._operations import WorkbenchesOperations  # type: ignore
from ._operations import ManagedComputeCapacitiesOperations  # type: ignore
from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import TestRaiExternalSafetyProviderOperations  # type: ignore
from ._operations import RaiExternalSafetyProviderOperations  # type: ignore
from ._operations import RaiExternalSafetyProvidersOperations  # type: ignore
from ._operations import AccountConnectionsOperations  # type: ignore
from ._operations import AccountCapabilityHostsOperations  # type: ignore
from ._operations import OutboundRuleOperations  # type: ignore
from ._operations import ManagedNetworkSettingsOperations  # type: ignore
from ._operations import OutboundRulesOperations  # type: ignore
from ._operations import ManagedNetworkProvisionsOperations  # type: ignore
from ._operations import AgentDeploymentsOperations  # type: ignore
from ._operations import ResourceSkusOperations  # type: ignore
from ._operations import UsagesOperations  # type: ignore
from ._operations import CommitmentTiersOperations  # type: ignore
from ._operations import ModelsOperations  # type: ignore
from ._operations import LocationBasedModelCapacitiesOperations  # type: ignore
from ._operations import ModelCapacitiesOperations  # type: ignore
from ._operations import _CognitiveServicesManagementClientOperationsMixin  # type: ignore # pylint: disable=unused-import

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "AccountsOperations",
    "DeletedAccountsOperations",
    "PrivateEndpointConnectionsOperations",
    "DeploymentsOperations",
    "CommitmentPlansOperations",
    "EncryptionScopesOperations",
    "RaiPoliciesOperations",
    "SubscriptionRaiPolicyOperations",
    "RaiBlocklistItemsOperations",
    "RaiBlocklistsOperations",
    "RaiTopicsOperations",
    "RaiToolLabelsOperations",
    "RaiContentFiltersOperations",
    "NetworkSecurityPerimeterConfigurationsOperations",
    "DefenderForAISettingsOperations",
    "ProjectsOperations",
    "ProjectConnectionsOperations",
    "ProjectCapabilityHostsOperations",
    "QuotaTiersOperations",
    "AgentApplicationsOperations",
    "ManagedComputeDeploymentsOperations",
    "ComputeOperationsOperations",
    "ManagedComputeUsagesOperationGroupOperations",
    "ComputesOperations",
    "WorkbenchesOperations",
    "ManagedComputeCapacitiesOperations",
    "PrivateLinkResourcesOperations",
    "TestRaiExternalSafetyProviderOperations",
    "RaiExternalSafetyProviderOperations",
    "RaiExternalSafetyProvidersOperations",
    "AccountConnectionsOperations",
    "AccountCapabilityHostsOperations",
    "OutboundRuleOperations",
    "ManagedNetworkSettingsOperations",
    "OutboundRulesOperations",
    "ManagedNetworkProvisionsOperations",
    "AgentDeploymentsOperations",
    "ResourceSkusOperations",
    "UsagesOperations",
    "CommitmentTiersOperations",
    "ModelsOperations",
    "LocationBasedModelCapacitiesOperations",
    "ModelCapacitiesOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
