# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AADAuthTypeConnectionProperties,
    AbusePenalty,
    AccessKeyAuthTypeConnectionProperties,
    Account,
    AccountKeyAuthTypeConnectionProperties,
    AccountModel,
    AccountProperties,
    AccountSku,
    AccountSkuListResult,
    AgentApplication,
    AgentDeployment,
    AgentDeploymentProperties,
    AgentProtocolVersion,
    AgentReference,
    AgentReferenceProperties,
    AgentReferenceResourceArmPaginatedResult,
    AgenticApplicationProperties,
    ApiKeyAuthConnectionProperties,
    ApiKeys,
    ApiProperties,
    ApplicationAuthorizationPolicy,
    ApplicationTrafficRoutingPolicy,
    AssignedIdentity,
    BillingMeterInfo,
    CalculateModelCapacityParameter,
    CalculateModelCapacityResult,
    CalculateModelCapacityResultEstimatedCapacity,
    CallRateLimit,
    CapabilityHost,
    CapabilityHostProperties,
    CapacityConfig,
    ChannelsBuiltInAuthorizationPolicy,
    CheckDomainAvailabilityParameter,
    CheckSkuAvailabilityParameter,
    ClusterComputeProperties,
    CommitmentCost,
    CommitmentPeriod,
    CommitmentPlan,
    CommitmentPlanAccountAssociation,
    CommitmentPlanAccountAssociationProperties,
    CommitmentPlanAssociation,
    CommitmentPlanProperties,
    CommitmentQuota,
    CommitmentTier,
    Compute,
    ComputeOperationStatus,
    ComputeOperationStatusProperties,
    ComputeProperties,
    ConnectionAccessKey,
    ConnectionAccountKey,
    ConnectionApiKey,
    ConnectionManagedIdentity,
    ConnectionOAuth2,
    ConnectionPersonalAccessToken,
    ConnectionPropertiesV2,
    ConnectionPropertiesV2BasicResource,
    ConnectionServicePrincipal,
    ConnectionSharedAccessSignature,
    ConnectionUpdateContent,
    ConnectionUsernamePassword,
    ConnectivityEndpoints,
    ContainerInstanceComputeProperties,
    CustomBlocklistConfig,
    CustomKeys,
    CustomKeysConnectionProperties,
    DefenderForAISetting,
    DefenderForAISettingProperties,
    Deployment,
    DeploymentCapacitySettings,
    DeploymentModel,
    DeploymentPolicyEvaluationResult,
    DeploymentProperties,
    DeploymentRouting,
    DeploymentScaleSettings,
    DeploymentSizeCapacity,
    DeploymentSpeculativeDecoding,
    DomainAvailability,
    Encryption,
    EncryptionScope,
    EncryptionScopeProperties,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorResponse,
    EvaluateDeploymentPoliciesDeployment,
    EvaluateDeploymentPoliciesDeploymentProperties,
    EvaluateDeploymentPoliciesRequest,
    EvaluateDeploymentPoliciesResponse,
    FoundryAutoUpgrade,
    FqdnOutboundRule,
    HostedAgentDeployment,
    Identity,
    IpRule,
    KeyVaultProperties,
    ManagedAgentDeployment,
    ManagedComputeCapacity,
    ManagedComputeCapacityProperties,
    ManagedComputeDeployment,
    ManagedComputeDeploymentInfo,
    ManagedComputeDeploymentProperties,
    ManagedComputeDeploymentProvisioningDetails,
    ManagedComputeDeploymentRoutes,
    ManagedComputeUsage,
    ManagedIdentityAuthTypeConnectionProperties,
    ManagedNetworkProvisionOptions,
    ManagedNetworkProvisionStatus,
    ManagedNetworkSettings,
    ManagedNetworkSettingsBasicResource,
    ManagedNetworkSettingsEx,
    ManagedNetworkSettingsProperties,
    ManagedNetworkSettingsPropertiesBasicResource,
    MetricName,
    Model,
    ModelCapacityCalculatorWorkload,
    ModelCapacityCalculatorWorkloadRequestParam,
    ModelCapacityListResultValueItem,
    ModelDeprecationInfo,
    ModelSku,
    ModelSkuCapacityProperties,
    MultiRegionSettings,
    NetworkInjection,
    NetworkRuleSet,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterAccessRule,
    NetworkSecurityPerimeterAccessRuleProperties,
    NetworkSecurityPerimeterAccessRulePropertiesSubscriptionsItem,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationAssociationInfo,
    NetworkSecurityPerimeterConfigurationProperties,
    NetworkSecurityPerimeterProfileInfo,
    NoneAuthTypeConnectionProperties,
    OAuth2AuthTypeConnectionProperties,
    Operation,
    OperationDisplay,
    OrganizationSharedBuiltInAuthorizationPolicy,
    OutboundRule,
    OutboundRuleBasicResource,
    PATAuthTypeConnectionProperties,
    PatchResourceSku,
    PatchResourceTags,
    PatchResourceTagsAndSku,
    PolicyAssignmentEvaluationDetails,
    PolicyExpressionEvaluationDetails,
    Pool,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionListResult,
    PrivateEndpointConnectionProperties,
    PrivateEndpointOutboundRule,
    PrivateEndpointOutboundRuleDestination,
    PrivateLinkResource,
    PrivateLinkResourceListResult,
    PrivateLinkResourceProperties,
    PrivateLinkServiceConnectionState,
    Project,
    ProjectCapabilityHost,
    ProjectCapabilityHostProperties,
    ProjectProperties,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    QuotaLimit,
    QuotaTier,
    QuotaTierProperties,
    QuotaTierUpgradeEligibilityInfo,
    RaiBlocklist,
    RaiBlocklistConfig,
    RaiBlocklistItem,
    RaiBlocklistItemBulkRequest,
    RaiBlocklistItemProperties,
    RaiBlocklistProperties,
    RaiContentFilter,
    RaiContentFilterProperties,
    RaiEgressHeaderTransform,
    RaiEgressHeaderValueRef,
    RaiEgressManagedIdentityRef,
    RaiEgressPolicyConfig,
    RaiEgressRewriteTarget,
    RaiEgressRule,
    RaiEgressRuleAction,
    RaiEgressRuleMatch,
    RaiEgressSecretRef,
    RaiExternalSafetyProviderSchema,
    RaiExternalSafetyProviderSchemaProperties,
    RaiMonitorConfig,
    RaiPolicy,
    RaiPolicyContentFilter,
    RaiPolicyProperties,
    RaiSafetyProviderConfig,
    RaiToolLabel,
    RaiToolLabelProperties,
    RaiToolLabelPropertiesAccountScope,
    RaiToolLabelPropertiesProjectScopesItem,
    RaiTopic,
    RaiTopicProperties,
    RegenerateKeyParameters,
    RegionSetting,
    ReplacementConfig,
    RequestMatchPattern,
    Resource,
    ResourceBase,
    ResourceSku,
    ResourceSkuRestrictionInfo,
    ResourceSkuRestrictions,
    RoleBasedBuiltInAuthorizationPolicy,
    SASAuthTypeConnectionProperties,
    SafetyProviderConfig,
    ServicePrincipalAuthTypeConnectionProperties,
    ServiceTagOutboundRule,
    ServiceTagOutboundRuleDestination,
    Sku,
    SkuAvailability,
    SkuAvailabilityListResult,
    SkuCapability,
    SkuChangeInfo,
    SkuResource,
    SshSettings,
    SystemData,
    ThrottlingRule,
    TrafficRoutingRule,
    Usage,
    UsageListResult,
    UserAssignedIdentity,
    UserOwnedAmlWorkspace,
    UserOwnedStorage,
    UsernamePasswordAuthTypeConnectionProperties,
    VersionedAgentReference,
    VirtualNetworkRule,
    Workbench,
    WorkbenchProperties,
)

from ._enums import (  # type: ignore
    AbusePenaltyAction,
    ActionType,
    AgentDeploymentProvisioningState,
    AgentDeploymentState,
    AgentDeploymentType,
    AgentProtocol,
    AgenticApplicationProvisioningState,
    BuiltInAuthorizationScheme,
    ByPassSelection,
    CapabilityHostKind,
    CapabilityHostProvisioningState,
    CommitmentPlanProvisioningState,
    ComputeOperationStatusType,
    ComputeProvisioningState,
    ComputeType,
    ConnectionAuthType,
    ConnectionCategory,
    ConnectionGroup,
    ContentLevel,
    CreatedByType,
    DefenderForAISettingState,
    DeploymentModelVersionUpgradeOption,
    DeploymentProvisioningState,
    DeploymentScaleType,
    DeploymentState,
    DeprecationStatus,
    EncryptionScopeProvisioningState,
    EncryptionScopeState,
    FirewallSku,
    FoundryAutoUpgradeMode,
    HostingModel,
    IdentityKind,
    IdentityManagementType,
    IdentityProvisioningState,
    IsolationMode,
    KeyName,
    KeySource,
    ManagedNetworkKind,
    ManagedNetworkProvisioningState,
    ManagedNetworkStatus,
    ManagedPERequirement,
    ManagedPEStatus,
    ModelLifecycleStatus,
    NetworkRuleAction,
    NspAccessRuleDirection,
    Origin,
    PolicyEvaluationOutcome,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    ProvisioningState,
    PublicNetworkAccess,
    QuotaScopeType,
    QuotaUsageStatus,
    RaiActionType,
    RaiEgressDefaultAction,
    RaiEgressHeaderOperation,
    RaiEgressMode,
    RaiEgressRuleActionType,
    RaiEgressRuleType,
    RaiEgressScheme,
    RaiPolicyContentSource,
    RaiPolicyMode,
    RaiPolicyType,
    ResourceIdentityType,
    ResourceSkuRestrictionsReasonCode,
    ResourceSkuRestrictionsType,
    RoutingMethods,
    RoutingMode,
    RuleAction,
    RuleCategory,
    RuleStatus,
    RuleType,
    ScenarioType,
    ServiceTier,
    SkuTier,
    TierUpgradePolicy,
    TrafficRoutingProtocol,
    UnitType,
    UpgradeAvailabilityStatus,
    VmPriority,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AADAuthTypeConnectionProperties",
    "AbusePenalty",
    "AccessKeyAuthTypeConnectionProperties",
    "Account",
    "AccountKeyAuthTypeConnectionProperties",
    "AccountModel",
    "AccountProperties",
    "AccountSku",
    "AccountSkuListResult",
    "AgentApplication",
    "AgentDeployment",
    "AgentDeploymentProperties",
    "AgentProtocolVersion",
    "AgentReference",
    "AgentReferenceProperties",
    "AgentReferenceResourceArmPaginatedResult",
    "AgenticApplicationProperties",
    "ApiKeyAuthConnectionProperties",
    "ApiKeys",
    "ApiProperties",
    "ApplicationAuthorizationPolicy",
    "ApplicationTrafficRoutingPolicy",
    "AssignedIdentity",
    "BillingMeterInfo",
    "CalculateModelCapacityParameter",
    "CalculateModelCapacityResult",
    "CalculateModelCapacityResultEstimatedCapacity",
    "CallRateLimit",
    "CapabilityHost",
    "CapabilityHostProperties",
    "CapacityConfig",
    "ChannelsBuiltInAuthorizationPolicy",
    "CheckDomainAvailabilityParameter",
    "CheckSkuAvailabilityParameter",
    "ClusterComputeProperties",
    "CommitmentCost",
    "CommitmentPeriod",
    "CommitmentPlan",
    "CommitmentPlanAccountAssociation",
    "CommitmentPlanAccountAssociationProperties",
    "CommitmentPlanAssociation",
    "CommitmentPlanProperties",
    "CommitmentQuota",
    "CommitmentTier",
    "Compute",
    "ComputeOperationStatus",
    "ComputeOperationStatusProperties",
    "ComputeProperties",
    "ConnectionAccessKey",
    "ConnectionAccountKey",
    "ConnectionApiKey",
    "ConnectionManagedIdentity",
    "ConnectionOAuth2",
    "ConnectionPersonalAccessToken",
    "ConnectionPropertiesV2",
    "ConnectionPropertiesV2BasicResource",
    "ConnectionServicePrincipal",
    "ConnectionSharedAccessSignature",
    "ConnectionUpdateContent",
    "ConnectionUsernamePassword",
    "ConnectivityEndpoints",
    "ContainerInstanceComputeProperties",
    "CustomBlocklistConfig",
    "CustomKeys",
    "CustomKeysConnectionProperties",
    "DefenderForAISetting",
    "DefenderForAISettingProperties",
    "Deployment",
    "DeploymentCapacitySettings",
    "DeploymentModel",
    "DeploymentPolicyEvaluationResult",
    "DeploymentProperties",
    "DeploymentRouting",
    "DeploymentScaleSettings",
    "DeploymentSizeCapacity",
    "DeploymentSpeculativeDecoding",
    "DomainAvailability",
    "Encryption",
    "EncryptionScope",
    "EncryptionScopeProperties",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorResponse",
    "EvaluateDeploymentPoliciesDeployment",
    "EvaluateDeploymentPoliciesDeploymentProperties",
    "EvaluateDeploymentPoliciesRequest",
    "EvaluateDeploymentPoliciesResponse",
    "FoundryAutoUpgrade",
    "FqdnOutboundRule",
    "HostedAgentDeployment",
    "Identity",
    "IpRule",
    "KeyVaultProperties",
    "ManagedAgentDeployment",
    "ManagedComputeCapacity",
    "ManagedComputeCapacityProperties",
    "ManagedComputeDeployment",
    "ManagedComputeDeploymentInfo",
    "ManagedComputeDeploymentProperties",
    "ManagedComputeDeploymentProvisioningDetails",
    "ManagedComputeDeploymentRoutes",
    "ManagedComputeUsage",
    "ManagedIdentityAuthTypeConnectionProperties",
    "ManagedNetworkProvisionOptions",
    "ManagedNetworkProvisionStatus",
    "ManagedNetworkSettings",
    "ManagedNetworkSettingsBasicResource",
    "ManagedNetworkSettingsEx",
    "ManagedNetworkSettingsProperties",
    "ManagedNetworkSettingsPropertiesBasicResource",
    "MetricName",
    "Model",
    "ModelCapacityCalculatorWorkload",
    "ModelCapacityCalculatorWorkloadRequestParam",
    "ModelCapacityListResultValueItem",
    "ModelDeprecationInfo",
    "ModelSku",
    "ModelSkuCapacityProperties",
    "MultiRegionSettings",
    "NetworkInjection",
    "NetworkRuleSet",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterAccessRule",
    "NetworkSecurityPerimeterAccessRuleProperties",
    "NetworkSecurityPerimeterAccessRulePropertiesSubscriptionsItem",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationAssociationInfo",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NetworkSecurityPerimeterProfileInfo",
    "NoneAuthTypeConnectionProperties",
    "OAuth2AuthTypeConnectionProperties",
    "Operation",
    "OperationDisplay",
    "OrganizationSharedBuiltInAuthorizationPolicy",
    "OutboundRule",
    "OutboundRuleBasicResource",
    "PATAuthTypeConnectionProperties",
    "PatchResourceSku",
    "PatchResourceTags",
    "PatchResourceTagsAndSku",
    "PolicyAssignmentEvaluationDetails",
    "PolicyExpressionEvaluationDetails",
    "Pool",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionListResult",
    "PrivateEndpointConnectionProperties",
    "PrivateEndpointOutboundRule",
    "PrivateEndpointOutboundRuleDestination",
    "PrivateLinkResource",
    "PrivateLinkResourceListResult",
    "PrivateLinkResourceProperties",
    "PrivateLinkServiceConnectionState",
    "Project",
    "ProjectCapabilityHost",
    "ProjectCapabilityHostProperties",
    "ProjectProperties",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "QuotaLimit",
    "QuotaTier",
    "QuotaTierProperties",
    "QuotaTierUpgradeEligibilityInfo",
    "RaiBlocklist",
    "RaiBlocklistConfig",
    "RaiBlocklistItem",
    "RaiBlocklistItemBulkRequest",
    "RaiBlocklistItemProperties",
    "RaiBlocklistProperties",
    "RaiContentFilter",
    "RaiContentFilterProperties",
    "RaiEgressHeaderTransform",
    "RaiEgressHeaderValueRef",
    "RaiEgressManagedIdentityRef",
    "RaiEgressPolicyConfig",
    "RaiEgressRewriteTarget",
    "RaiEgressRule",
    "RaiEgressRuleAction",
    "RaiEgressRuleMatch",
    "RaiEgressSecretRef",
    "RaiExternalSafetyProviderSchema",
    "RaiExternalSafetyProviderSchemaProperties",
    "RaiMonitorConfig",
    "RaiPolicy",
    "RaiPolicyContentFilter",
    "RaiPolicyProperties",
    "RaiSafetyProviderConfig",
    "RaiToolLabel",
    "RaiToolLabelProperties",
    "RaiToolLabelPropertiesAccountScope",
    "RaiToolLabelPropertiesProjectScopesItem",
    "RaiTopic",
    "RaiTopicProperties",
    "RegenerateKeyParameters",
    "RegionSetting",
    "ReplacementConfig",
    "RequestMatchPattern",
    "Resource",
    "ResourceBase",
    "ResourceSku",
    "ResourceSkuRestrictionInfo",
    "ResourceSkuRestrictions",
    "RoleBasedBuiltInAuthorizationPolicy",
    "SASAuthTypeConnectionProperties",
    "SafetyProviderConfig",
    "ServicePrincipalAuthTypeConnectionProperties",
    "ServiceTagOutboundRule",
    "ServiceTagOutboundRuleDestination",
    "Sku",
    "SkuAvailability",
    "SkuAvailabilityListResult",
    "SkuCapability",
    "SkuChangeInfo",
    "SkuResource",
    "SshSettings",
    "SystemData",
    "ThrottlingRule",
    "TrafficRoutingRule",
    "Usage",
    "UsageListResult",
    "UserAssignedIdentity",
    "UserOwnedAmlWorkspace",
    "UserOwnedStorage",
    "UsernamePasswordAuthTypeConnectionProperties",
    "VersionedAgentReference",
    "VirtualNetworkRule",
    "Workbench",
    "WorkbenchProperties",
    "AbusePenaltyAction",
    "ActionType",
    "AgentDeploymentProvisioningState",
    "AgentDeploymentState",
    "AgentDeploymentType",
    "AgentProtocol",
    "AgenticApplicationProvisioningState",
    "BuiltInAuthorizationScheme",
    "ByPassSelection",
    "CapabilityHostKind",
    "CapabilityHostProvisioningState",
    "CommitmentPlanProvisioningState",
    "ComputeOperationStatusType",
    "ComputeProvisioningState",
    "ComputeType",
    "ConnectionAuthType",
    "ConnectionCategory",
    "ConnectionGroup",
    "ContentLevel",
    "CreatedByType",
    "DefenderForAISettingState",
    "DeploymentModelVersionUpgradeOption",
    "DeploymentProvisioningState",
    "DeploymentScaleType",
    "DeploymentState",
    "DeprecationStatus",
    "EncryptionScopeProvisioningState",
    "EncryptionScopeState",
    "FirewallSku",
    "FoundryAutoUpgradeMode",
    "HostingModel",
    "IdentityKind",
    "IdentityManagementType",
    "IdentityProvisioningState",
    "IsolationMode",
    "KeyName",
    "KeySource",
    "ManagedNetworkKind",
    "ManagedNetworkProvisioningState",
    "ManagedNetworkStatus",
    "ManagedPERequirement",
    "ManagedPEStatus",
    "ModelLifecycleStatus",
    "NetworkRuleAction",
    "NspAccessRuleDirection",
    "Origin",
    "PolicyEvaluationOutcome",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "ProvisioningState",
    "PublicNetworkAccess",
    "QuotaScopeType",
    "QuotaUsageStatus",
    "RaiActionType",
    "RaiEgressDefaultAction",
    "RaiEgressHeaderOperation",
    "RaiEgressMode",
    "RaiEgressRuleActionType",
    "RaiEgressRuleType",
    "RaiEgressScheme",
    "RaiPolicyContentSource",
    "RaiPolicyMode",
    "RaiPolicyType",
    "ResourceIdentityType",
    "ResourceSkuRestrictionsReasonCode",
    "ResourceSkuRestrictionsType",
    "RoutingMethods",
    "RoutingMode",
    "RuleAction",
    "RuleCategory",
    "RuleStatus",
    "RuleType",
    "ScenarioType",
    "ServiceTier",
    "SkuTier",
    "TierUpgradePolicy",
    "TrafficRoutingProtocol",
    "UnitType",
    "UpgradeAvailabilityStatus",
    "VmPriority",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
